@@ -11,7 +11,8 @@ class WebPushForm(forms.Form):
                                     ])
 
     def save_or_delete(self, subscription, user, status_type, group_name):
-        data = {}
+        # Ensure get_or_create matches exactly
+        data = {"user": None, "group": None}
 
         if user.is_authenticated:
             data["user"] = user
